@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2018-01-19 11:51:05 +0200 (Pn, 19 saus. 2018) $ 
-#$Revision: 5954 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/CIF/DDL/Ranges.pm $
+#$Author: antanas $
+#$Date: 2019-04-23 01:57:49 +0300 (Tue, 23 Apr 2019) $ 
+#$Revision: 6975 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.5/src/lib/perl5/COD/CIF/DDL/Ranges.pm $
 #------------------------------------------------------------------------------
 #*
 #* A set of subroutines for handling ranges as defined in the Dictionary
@@ -239,9 +239,9 @@ sub is_in_range_char
     my $range = $param->{'range'};
 
     if(
-        ( !exists $param->[0] || $value ge $range->[0] )
+        ( !defined $range->[0] || $value ge $range->[0] )
         &&
-        ( defined $range->[1] || $value le $range->[1] )
+        ( !defined $range->[1] || $value le $range->[1] )
     ) {
         return 1;
     }
