@@ -1,13 +1,13 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2019-02-27 09:31:50 +0200 (Tr, 27 vas. 2019) $ 
+#$Date: 2019-11-07 17:03:02 +0200 (Thu, 07 Nov 2019) $ 
 #$Revision: 1551 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/CIF/Data/SymmetryGenerator.pm $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.5/src/lib/perl5/COD/CIF/Data/SymmetryGenerator.pm $
 #------------------------------------------------------------------------------
 #*
 #  Calculate unit cell contents from the atomic coordinates and
-#  symmetry information in the CIF data structure returned by the
-#  CIFParser.
+#  symmetry information in the CIF data structure as returned by the
+#  COD::CIF::Parser.
 #**
 
 package COD::CIF::Data::SymmetryGenerator;
@@ -202,6 +202,7 @@ sub symop_register_applied_symop($$@)
     # FIXME: the symmetry operation list is currently optional in the
     # atom object. The following code fails if the list is not provided
     $new_atom_info->{symop} = $symop_now;
+    print STDERR ">>>> $symop_string\n" unless exists $new_atom_info->{symop_list}{symop_ids}{$symop_string};
     $new_atom_info->{symop_id} =
         $new_atom_info->{symop_list}
                         {symop_ids}
